@@ -35,7 +35,6 @@ __all__ = [
     "export",
     "stdout",
     "Settings",
-    "RequiredProviders",
     "RequiredProvider",
 ]
 
@@ -68,4 +67,4 @@ from terrascript.core.lang.output import Output
 from terrascript.core.lang.resource import Resource, Lifecycle
 from terrascript.core.terraform.provider import Provider
 from terrascript.core.context import ctx, apply, destroy, plan, workspace, export, stdout
-from terrascript.core.terraform.settings import Settings, RequiredProviders, RequiredProvider
+from terrascript.core.terraform.settings import Settings, RequiredProvider
